import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "isReadOnly", "isDisabled", "placeholder", "isRequired", "helperText", "validateOnMount", "meta", "FormFieldGridProps", "HelpertextProps"];
import React from 'react';
import PropTypes from 'prop-types';
import FormTextArea from "semantic-ui-react/dist/es/collections/Form/FormTextArea.js";
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormField from '../form-field/form-field';

var Textarea = function Textarea(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      placeholder = _useFieldApi.placeholder,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      FormFieldGridProps = _useFieldApi.FormFieldGridProps,
      HelpertextProps = _useFieldApi.HelpertextProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = validationError(meta, validateOnMount);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelpertextProps: HelpertextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    required: isRequired,
    disabled: isDisabled,
    readOnly: isReadOnly
  }, input, {
    error: invalid && {
      content: meta.error || meta.submitError
    },
    control: FormTextArea
  }, rest)));
};

Textarea.propTypes = {
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  placeholder: PropTypes.node,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  helperText: PropTypes.node,
  validateOnMount: PropTypes.bool,
  description: PropTypes.node,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelpertextProps: PropTypes.object
};
Textarea.defaultProps = {
  FormFieldGridProps: {},
  HelpertextProps: {}
};
export default Textarea;